@@ -7,7 +7,7 @@ from deepfos_ipc_protocol.utils import (
     resolve_detaillist_protocol,
     logging
 )
-from configs import const
+from deepfos_ipc_protocol.configs import const
 
 
 HEADER_PROTOCOL = const.HEADER_PROTOCOL
